@@ -115,9 +115,9 @@ pub struct Cli {
     #[arg(long)]
     pub verbose: bool,
 
-    /// Show only restrictive dependencies in strict mode
+    /// Show only restrictive dependencies
     #[arg(long, short)]
-    pub strict: bool,
+    pub restrictive: bool,
 
     /// Enable TUI table
     #[arg(long, short)]
@@ -162,6 +162,10 @@ pub struct Cli {
     /// Filter by OSI license approval status
     #[arg(long, value_enum)]
     pub osi: Option<OsiFilter>,
+
+    /// Enable strict mode for license parser
+    #[arg(long)]
+    pub strict: bool,
 }
 
 impl Cli {
@@ -401,7 +405,7 @@ mod tests {
             json: false,
             yaml: false,
             verbose: false,
-            strict: false,
+            restrictive: false,
             gui: false,
             language: None,
             ci_format: None,
@@ -413,11 +417,13 @@ mod tests {
             gist: false,
             sbom: None,
             osi: None,
+            strict: false,
         };
 
         assert_eq!(cli.path, "./");
         assert!(!cli.debug);
         assert!(!cli.json);
+        assert!(!cli.restrictive);
         assert!(!cli.strict);
         assert!(cli.is_default_command());
     }
@@ -439,7 +445,7 @@ mod tests {
             json: false,
             yaml: false,
             verbose: false,
-            strict: false,
+            restrictive: false,
             gui: false,
             language: None,
             ci_format: None,
@@ -451,6 +457,7 @@ mod tests {
             gist: false,
             sbom: None,
             osi: None,
+            strict: false,
         };
 
         let cmd = cli.get_command_args();
@@ -481,7 +488,7 @@ mod tests {
             json: false,
             yaml: false,
             verbose: false,
-            strict: false,
+            restrictive: false,
             gui: false,
             language: None,
             ci_format: None,
@@ -493,6 +500,7 @@ mod tests {
             gist: false,
             sbom: None,
             osi: None,
+            strict: false,
         };
 
         let cmd = cli.get_command_args();
