@@ -5,19 +5,9 @@ pub mod cpp;
 pub mod go;
 pub mod node;
 pub mod python;
+pub mod r;
 pub mod rust;
 
-// Re-export commonly used types and functions for backward compatibility
-// TODO: Remove when 1.8.5 is no longer supported
-pub use c::analyze_c_licenses;
-pub use cpp::analyze_cpp_licenses;
-pub use go::{
-    analyze_go_licenses, fetch_license_for_go_dependency, get_go_dependencies, GoPackages,
-};
-pub use node::{analyze_js_licenses, PackageJson};
-pub use python::{analyze_python_licenses, fetch_license_for_python_dependency};
-pub use rust::analyze_rust_licenses;
-
 use crate::licenses::LicenseInfo;
 use std::path::Path;
 
@@ -46,6 +36,7 @@ pub enum Language {
     Node(&'static str),
     Go(&'static str),
     Python(&'static [&'static str]),
+    R(&'static [&'static str]),
 }
 
 impl Language {
@@ -65,6 +56,8 @@ impl Language {
             _ => {
                 if PYTHON_PATHS.contains(&file_name) {
                     Some(Language::Python(&PYTHON_PATHS[..]))
+                } else if R_PATHS.contains(&file_name) {
+                    Some(Language::R(&R_PATHS[..]))
                 } else {
                     None
                 }
@@ -92,3 +85,6 @@ pub const PYTHON_PATHS: [&str; 4] = [
     "pip_freeze.txt",
     "pyproject.toml",
 ];
+
+/// R project file patterns
+pub const R_PATHS: [&str; 2] = ["DESCRIPTION", "renv.lock"];
