@@ -16,15 +16,6 @@ use crate::cli;
 use crate::config;
 use crate::debug::{log, log_debug, log_error, FeludaResult, LogLevel};
 
-// Re-export language-specific functions for backward compatibility
-// TODO: Remove when 1.8.5 is no longer supported
-#[allow(unused_imports)]
-pub use crate::languages::{
-    analyze_go_licenses, analyze_js_licenses, analyze_python_licenses, analyze_rust_licenses,
-    fetch_license_for_go_dependency, fetch_license_for_python_dependency, get_go_dependencies,
-    GoPackages, PackageJson,
-};
-
 /// License compatibility enum
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Serialize, Deserialize)]
 pub enum LicenseCompatibility {
@@ -565,10 +556,11 @@ pub fn get_osi_status(license_id: &str) -> OsiStatus {
 pub fn is_license_restrictive(
     license: &Option<String>,
     known_licenses: &HashMap<String, License>,
+    strict: bool,
 ) -> bool {
     log(
         LogLevel::Info,
-        &format!("Checking if license is restrictive: {license:?}"),
+        &format!("Checking if license is restrictive: {license:?} (strict={strict})"),
     );
 
     let config = match config::load_config() {
@@ -600,8 +592,18 @@ pub fn is_license_restrictive(
         if let Some(license_data) = known_licenses.get(license_str) {
             log_debug("Found license data", license_data);
 
-            const CONDITIONS: [&str; 2] = ["source-disclosure", "network-use-disclosure"];
-            let is_restrictive = CONDITIONS
+            let conditions = if strict {
+                vec![
+                    "source-disclosure",
+                    "network-use-disclosure",
+                    "disclose-source",
+                    "same-license",
+                ]
+            } else {
+                vec!["source-disclosure", "network-use-disclosure"]
+            };
+
+            let is_restrictive = conditions
                 .iter()
                 .any(|&condition| license_data.conditions.contains(&condition.to_string()));
 
@@ -619,12 +621,6 @@ pub fn is_license_restrictive(
 
             return is_restrictive;
         } else {
-            // Check against user-configured restrictive licenses
-            log_debug(
-                "Checking against configured restrictive licenses",
-                &config.licenses.restrictive,
-            );
-
             let is_restrictive = config
                 .licenses
                 .restrictive
@@ -636,6 +632,14 @@ pub fn is_license_restrictive(
                     LogLevel::Warn,
                     &format!("License {license_str} matches restrictive pattern in config"),
                 );
+            } else if strict && license_str.contains("Unknown") {
+                log(
+                    LogLevel::Warn,
+                    &format!(
+                        "License {license_str} is unknown in strict mode, considering restrictive"
+                    ),
+                );
+                return true;
             } else {
                 log(
                     LogLevel::Info,
@@ -647,6 +651,14 @@ pub fn is_license_restrictive(
         }
     }
 
+    if strict {
+        log(
+            LogLevel::Warn,
+            "No license information available in strict mode, considering restrictive",
+        );
+        return true;
+    }
+
     log(LogLevel::Warn, "No license information available");
     false
 }
@@ -802,18 +814,16 @@ fn get_compatibility_matrix() -> &'static HashMap<String, Vec<String>> {
 pub fn is_license_compatible(
     dependency_license: &str,
     project_license: &str,
+    strict: bool,
 ) -> LicenseCompatibility {
     log(
         LogLevel::Info,
         &format!(
-            "Checking if dependency license {dependency_license} is compatible with project license {project_license}"
+            "Checking if dependency license {dependency_license} is compatible with project license {project_license} (strict={strict})"
         ),
     );
 
-    // Get the compatibility matrix (loaded from external file or fallback)
     let compatibility_matrix = get_compatibility_matrix();
-
-    // Normalize license identifiers
     let norm_dependency_license = normalize_license_id(dependency_license);
     let norm_project_license = normalize_license_id(project_license);
 
@@ -824,7 +834,6 @@ pub fn is_license_compatible(
         ),
     );
 
-    // Check compatibility based on the matrix
     match compatibility_matrix.get(&norm_project_license) {
         Some(compatible_licenses) => {
             if compatible_licenses.contains(&norm_dependency_license) {
@@ -846,11 +855,19 @@ pub fn is_license_compatible(
             }
         }
         None => {
-            log(
-                LogLevel::Warn,
-                &format!("Unknown compatibility for project license {norm_project_license}"),
-            );
-            LicenseCompatibility::Unknown
+            if strict {
+                log(
+                    LogLevel::Warn,
+                    &format!("Unknown compatibility for project license {norm_project_license} in strict mode, marking as incompatible"),
+                );
+                LicenseCompatibility::Incompatible
+            } else {
+                log(
+                    LogLevel::Warn,
+                    &format!("Unknown compatibility for project license {norm_project_license}"),
+                );
+                LicenseCompatibility::Unknown
+            }
         }
     }
 }
@@ -1193,31 +1210,31 @@ mod tests {
     #[ignore] // Skip this test due to static initialization issues in test runner
     fn test_is_license_compatible_mit_project() {
         assert_eq!(
-            is_license_compatible("MIT", "MIT"),
+            is_license_compatible("MIT", "MIT", false),
             LicenseCompatibility::Compatible
         );
         assert_eq!(
-            is_license_compatible("BSD-2-Clause", "MIT"),
+            is_license_compatible("BSD-2-Clause", "MIT", false),
             LicenseCompatibility::Compatible
         );
         assert_eq!(
-            is_license_compatible("BSD-3-Clause", "MIT"),
+            is_license_compatible("BSD-3-Clause", "MIT", false),
             LicenseCompatibility::Compatible
         );
         assert_eq!(
-            is_license_compatible("Apache-2.0", "MIT"),
+            is_license_compatible("Apache-2.0", "MIT", false),
             LicenseCompatibility::Compatible
         );
         assert_eq!(
-            is_license_compatible("LGPL-3.0", "MIT"),
+            is_license_compatible("LGPL-3.0", "MIT", false),
             LicenseCompatibility::Incompatible
         );
         assert_eq!(
-            is_license_compatible("MPL-2.0", "MIT"),
+            is_license_compatible("MPL-2.0", "MIT", false),
             LicenseCompatibility::Incompatible
         );
         assert_eq!(
-            is_license_compatible("GPL-3.0", "MIT"),
+            is_license_compatible("GPL-3.0", "MIT", false),
             LicenseCompatibility::Incompatible
         );
     }
