@@ -32,7 +32,7 @@ struct CheckConfig {
     json: bool,
     yaml: bool,
     verbose: bool,
-    strict: bool,
+    restrictive: bool,
     gui: bool,
     language: Option<String>,
     ci_format: Option<cli::CiFormat>,
@@ -43,6 +43,7 @@ struct CheckConfig {
     project_license: Option<String>,
     gist: bool,
     osi: Option<cli::OsiFilter>,
+    strict: bool,
 }
 
 fn main() {
@@ -82,7 +83,7 @@ fn run() -> FeludaResult<()> {
                 &format!("Attempting to clone repository: {repo_url}"),
             );
             let temp_dir = TempDir::new().map_err(|e| {
-                FeludaError::Unknown(format!("Failed to create temporary directory: {e}"))
+                FeludaError::TempDir(format!("Failed to create temporary directory: {e}"))
             })?;
             let repo_path = temp_dir.path();
 
@@ -129,7 +130,7 @@ fn run() -> FeludaResult<()> {
             json: args.json,
             yaml: args.yaml,
             verbose: args.verbose,
-            strict: args.strict,
+            restrictive: args.restrictive,
             gui: args.gui,
             language: args.language,
             ci_format: args.ci_format,
@@ -140,6 +141,7 @@ fn run() -> FeludaResult<()> {
             project_license: args.project_license,
             gist: args.gist,
             osi: args.osi,
+            strict: args.strict,
         };
         handle_check_command(config)
     } else {
@@ -207,7 +209,7 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
     }
 
     // Parse and analyze dependencies
-    let mut analyzed_data = parse_root(&config.path, config.language.as_deref())
+    let mut analyzed_data = parse_root(&config.path, config.language.as_deref(), config.strict)
         .map_err(|e| FeludaError::Parser(format!("Failed to parse dependencies: {e}")))?;
 
     log_debug("Analyzed dependencies", &analyzed_data);
@@ -226,7 +228,8 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
 
         for info in &mut analyzed_data {
             if let Some(ref dep_license) = info.license {
-                info.compatibility = is_license_compatible(dep_license, proj_license);
+                info.compatibility =
+                    is_license_compatible(dep_license, proj_license, config.strict);
 
                 log(
                     LogLevel::Info,
@@ -236,13 +239,22 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
                     ),
                 );
             } else {
-                info.compatibility = LicenseCompatibility::Unknown;
+                info.compatibility = if config.strict {
+                    LicenseCompatibility::Incompatible
+                } else {
+                    LicenseCompatibility::Unknown
+                };
 
                 log(
                     LogLevel::Info,
                     &format!(
-                        "License compatibility for {} unknown (no license info)",
-                        info.name
+                        "License compatibility for {} {} (no license info)",
+                        info.name,
+                        if config.strict {
+                            "incompatible"
+                        } else {
+                            "unknown"
+                        }
                     ),
                 );
             }
@@ -264,14 +276,14 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
         let original_count = analyzed_data.len();
 
         // Filter for restrictive and incompatible
-        if config.strict || config.incompatible {
+        if config.restrictive || config.incompatible {
             if project_license.is_some() {
                 log(
                 LogLevel::Info,
-                "Strict and incompatible mode enabled, filtering for restrictive and incompatible licenses",
+                "Restrictive and incompatible mode enabled, filtering for restrictive and incompatible licenses",
             );
                 analyzed_data.retain(|info| {
-                    (config.strict && *info.is_restrictive())
+                    (config.restrictive && *info.is_restrictive())
                         || (config.incompatible
                             && info.compatibility == LicenseCompatibility::Incompatible)
                 });
@@ -290,11 +302,11 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
                 "Incompatible mode enabled but no project license specified, cannot filter for incompatible licenses",
             );
             }
-        } else if config.strict {
+        } else if config.restrictive {
             // Filter for restrictive
             log(
                 LogLevel::Info,
-                "Strict mode enabled, filtering for restrictive licenses",
+                "Restrictive mode enabled, filtering for restrictive licenses",
             );
             analyzed_data.retain(|info| *info.is_restrictive());
 
@@ -377,7 +389,7 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
 
         // Initialize the terminal
         color_eyre::install()
-            .map_err(|e| FeludaError::Unknown(format!("Failed to initialize color_eyre: {e}")))?;
+            .map_err(|e| FeludaError::TuiInit(format!("Failed to initialize color_eyre: {e}")))?;
 
         let terminal = ratatui::init();
         log(LogLevel::Info, "Terminal initialized for TUI");
@@ -387,7 +399,7 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
         ratatui::restore();
 
         // Handle any errors from the TUI
-        app_result.map_err(|e| FeludaError::Unknown(format!("TUI error: {e}")))?;
+        app_result.map_err(|e| FeludaError::TuiRuntime(format!("TUI error: {e}")))?;
 
         log(LogLevel::Info, "TUI session completed successfully");
     } else {
@@ -398,7 +410,7 @@ fn handle_check_command(config: CheckConfig) -> FeludaResult<()> {
             config.json,
             config.yaml,
             config.verbose,
-            config.strict,
+            config.restrictive,
             config.incompatible,
             config.ci_format,
             config.output_file,
