@@ -2,7 +2,12 @@
 
 use crate::cli;
 use crate::debug::{log, log_debug, FeludaResult, LogLevel};
-use crate::languages::{Language, CPP_PATHS, C_PATHS, PYTHON_PATHS};
+use crate::languages::{
+    c::analyze_c_licenses, cpp::analyze_cpp_licenses, go::analyze_go_licenses,
+    node::analyze_js_licenses, python::analyze_python_licenses, r::analyze_r_licenses,
+    rust::analyze_rust_licenses,
+};
+use crate::languages::{Language, CPP_PATHS, C_PATHS, PYTHON_PATHS, R_PATHS};
 use crate::licenses::{
     detect_project_license, is_license_compatible, LicenseCompatibility, LicenseInfo,
 };
@@ -147,12 +152,37 @@ fn check_which_python_file_exists(project_path: impl AsRef<Path>) -> Option<Stri
     None
 }
 
+/// Check which R project file exists in the given path
+fn check_which_r_file_exists(project_path: impl AsRef<Path>) -> Option<String> {
+    for &path in R_PATHS.iter() {
+        let full_path = Path::new(project_path.as_ref()).join(path);
+        if full_path.exists() {
+            log(
+                LogLevel::Info,
+                &format!("Found R project file: {}", full_path.display()),
+            );
+            return Some(path.to_string());
+        }
+    }
+
+    log(
+        LogLevel::Warn,
+        &format!(
+            "No R project file found in: {}",
+            project_path.as_ref().display()
+        ),
+    );
+    None
+}
+
 /// Main entry point for parsing project dependencies
 pub fn parse_root(
     root_path: impl AsRef<Path>,
     language: Option<&str>,
+    strict: bool,
 ) -> FeludaResult<Vec<LicenseInfo>> {
-    let config = crate::config::load_config()?;
+    let mut config = crate::config::load_config()?;
+    config.strict = strict;
     parse_root_with_config(root_path, language, &config)
 }
 
@@ -179,7 +209,7 @@ pub fn parse_root_with_config(
         );
         println!(
             "❌ No supported project files found.\n\
-            Feluda supports: C, C++, Rust, Node.js, Go, Python"
+            Feluda supports: C, C++, Rust, Node.js, Go, Python, R"
         );
         return Ok(Vec::new());
     }
@@ -248,7 +278,7 @@ fn set_license_compatibility(licenses: &mut [LicenseInfo], project_license: &Opt
     for license in licenses {
         license.compatibility = match (project_license, &license.license) {
             (Some(proj_license), Some(dep_license)) => {
-                is_license_compatible(dep_license, proj_license)
+                is_license_compatible(dep_license, proj_license, false)
             }
             _ => LicenseCompatibility::Unknown,
         };
@@ -265,6 +295,7 @@ fn matches_language(project_type: Language, language: &str) -> bool {
             | (Language::Node(_), "node")
             | (Language::Go(_), "go")
             | (Language::Python(_), "python")
+            | (Language::R(_), "r")
     )
 }
 
@@ -301,7 +332,7 @@ fn parse_dependencies(
                             metadata.packages.len()
                         ));
 
-                        crate::languages::analyze_rust_licenses(metadata.packages)
+                        analyze_rust_licenses(metadata.packages)
                     }
                     Err(err) => {
                         log(
@@ -323,7 +354,7 @@ fn parse_dependencies(
 
                 match project_path.to_str() {
                     Some(path_str) => {
-                        let deps = crate::languages::analyze_js_licenses(path_str);
+                        let deps = analyze_js_licenses(path_str);
                         indicator.update_progress(&format!("found {} dependencies", deps.len()));
                         deps
                     }
@@ -344,7 +375,7 @@ fn parse_dependencies(
 
                 match project_path.to_str() {
                     Some(path_str) => {
-                        let deps = crate::languages::analyze_go_licenses(path_str, config);
+                        let deps = analyze_go_licenses(path_str, config);
                         indicator.update_progress(&format!("found {} dependencies", deps.len()));
                         deps
                     }
@@ -366,7 +397,7 @@ fn parse_dependencies(
 
                     match project_path.to_str() {
                         Some(path_str) => {
-                            let deps = crate::languages::analyze_python_licenses(path_str, config);
+                            let deps = analyze_python_licenses(path_str, config);
                             indicator
                                 .update_progress(&format!("found {} dependencies", deps.len()));
                             deps
@@ -394,7 +425,7 @@ fn parse_dependencies(
 
                     match project_path.to_str() {
                         Some(path_str) => {
-                            let deps = crate::languages::analyze_c_licenses(path_str, config);
+                            let deps = analyze_c_licenses(path_str, config);
                             indicator
                                 .update_progress(&format!("found {} dependencies", deps.len()));
                             deps
@@ -422,7 +453,7 @@ fn parse_dependencies(
 
                     match project_path.to_str() {
                         Some(path_str) => {
-                            let deps = crate::languages::analyze_cpp_licenses(path_str, config);
+                            let deps = analyze_cpp_licenses(path_str, config);
                             indicator
                                 .update_progress(&format!("found {} dependencies", deps.len()));
                             deps
@@ -438,6 +469,34 @@ fn parse_dependencies(
                     Vec::new()
                 }
             },
+            Language::R(_) => match check_which_r_file_exists(project_path) {
+                Some(r_package_file) => {
+                    let project_path = Path::new(project_path).join(&r_package_file);
+                    log(
+                        LogLevel::Info,
+                        &format!("Parsing R project: {}", project_path.display()),
+                    );
+
+                    indicator.update_progress(&format!("analyzing {r_package_file}"));
+
+                    match project_path.to_str() {
+                        Some(path_str) => {
+                            let deps = analyze_r_licenses(path_str, config);
+                            indicator
+                                .update_progress(&format!("found {} dependencies", deps.len()));
+                            deps
+                        }
+                        None => {
+                            log(LogLevel::Error, "Failed to convert R path to string");
+                            Vec::new()
+                        }
+                    }
+                }
+                None => {
+                    log(LogLevel::Error, "R package file not found");
+                    Vec::new()
+                }
+            },
         }
     });
 
@@ -540,35 +599,35 @@ mod tests {
         std::fs::write(root_path.join("requirements.txt"), "# No dependencies").unwrap();
 
         // Test filtering by node
-        let result = parse_root(root_path, Some("node"));
+        let result = parse_root(root_path, Some("node"), false);
         assert!(result.is_ok());
 
         // Test filtering by go
-        let result = parse_root(root_path, Some("go"));
+        let result = parse_root(root_path, Some("go"), false);
         assert!(result.is_ok());
 
         // Test filtering by python
-        let result = parse_root(root_path, Some("python"));
+        let result = parse_root(root_path, Some("python"), false);
         assert!(result.is_ok());
 
         // Test filtering by non-existent language
-        let result = parse_root(root_path, Some("java"));
+        let result = parse_root(root_path, Some("java"), false);
         assert!(result.is_ok());
         let licenses = result.unwrap();
         assert!(licenses.is_empty());
 
         // Test case-insensitive filtering
-        let result = parse_root(root_path, Some("NODE"));
+        let result = parse_root(root_path, Some("NODE"), false);
         assert!(result.is_ok());
 
-        let result = parse_root(root_path, Some("Python"));
+        let result = parse_root(root_path, Some("Python"), false);
         assert!(result.is_ok());
     }
 
     #[test]
     fn test_parse_root_no_projects() {
         let temp_dir = tempfile::TempDir::new().unwrap();
-        let result = parse_root(temp_dir.path(), None).unwrap();
+        let result = parse_root(temp_dir.path(), None, false).unwrap();
         assert!(result.is_empty());
     }
 
@@ -591,7 +650,7 @@ mod tests {
         std::fs::write(root_path.join("go.mod"), "module test\n\ngo 1.19").unwrap();
         std::fs::write(root_path.join("requirements.txt"), "# No dependencies").unwrap();
 
-        let result = parse_root(root_path, None);
+        let result = parse_root(root_path, None, false);
         assert!(result.is_ok());
     }
 
@@ -697,7 +756,7 @@ mod tests {
 
     #[test]
     fn test_parse_root_invalid_path() {
-        let result = parse_root("/definitely/nonexistent/path", None);
+        let result = parse_root("/definitely/nonexistent/path", None, false);
         assert!(result.is_ok());
         let licenses = result.unwrap();
         assert!(licenses.is_empty());
