@@ -213,7 +213,7 @@ pub fn clone_repository(args: &Cli, dest_path: &Path) -> FeludaResult<()> {
                         }
                         Err(e) => {
                             log(LogLevel::Error, &format!("HTTPS clone failed: {e}"));
-                            Err(FeludaError::Unknown(format!(
+                            Err(FeludaError::RepositoryClone(format!(
                                 "Failed to clone repository: {e}"
                             )))
                         }
@@ -221,7 +221,7 @@ pub fn clone_repository(args: &Cli, dest_path: &Path) -> FeludaResult<()> {
                 }
             }
             log(LogLevel::Error, &format!("Failed to clone repository: {e}"));
-            Err(FeludaError::Unknown(format!(
+            Err(FeludaError::RepositoryClone(format!(
                 "Failed to clone repository: {e}"
             )))
         }
@@ -427,7 +427,7 @@ mod tests {
             json: false,
             yaml: false,
             verbose: false,
-            strict: false,
+            restrictive: false,
             gui: false,
             language: None,
             ci_format: None,
@@ -439,6 +439,7 @@ mod tests {
             gist: false,
             sbom: None,
             osi: None,
+            strict: false,
         };
 
         let result = clone_repository(&args, temp_dir.path());
@@ -481,7 +482,7 @@ mod tests {
             json: false,
             yaml: false,
             verbose: false,
-            strict: false,
+            restrictive: false,
             gui: false,
             language: None,
             ci_format: None,
@@ -493,6 +494,7 @@ mod tests {
             gist: false,
             sbom: None,
             osi: None,
+            strict: false,
         };
 
         // Enable debug mode for this test
@@ -534,7 +536,7 @@ mod tests {
             json: false,
             yaml: false,
             verbose: false,
-            strict: false,
+            restrictive: false,
             gui: false,
             language: None,
             ci_format: None,
@@ -546,6 +548,7 @@ mod tests {
             gist: false,
             sbom: None,
             osi: None,
+            strict: false,
         };
 
         let result = clone_repository(&args, temp_dir.path());
